@@ -38,7 +38,7 @@ elo.update.default <- function(wins.A, elo.A, elo.B, k, ..., adjust.A = 0, adjus
 elo.update.formula <- function(formula, data, na.action, subset, k = NULL, ...)
 {
   Call <- match.call()
-  Call[[1L]] <- quote(elo.model.frame)
+  Call[[1L]] <- quote(elo::elo.model.frame)
   Call$required.vars <- c("wins", "elos", "k")
   mf <- eval(Call, parent.frame())
   elo.update(mf$wins.A, mf$elo.A, mf$elo.B, k = mf$k, ...,
