@@ -20,21 +20,6 @@
 NULL
 #> NULL
 
-null_or_length0 <- function(x) is.null(x) || length(x) == 0
-
-clean_elo_formula <- function(Terms)
-{
-  k.col <- attr(Terms, "specials")$k
-  grp.col <- attr(Terms, "specials")$group
-  reg.col <- attr(Terms, "specials")$regress
-
-  if(!null_or_length0(k.col) || !null_or_length0(grp.col) || !null_or_length0(reg.col))
-  {
-    Terms <- stats::drop.terms(Terms, dropx = c(k.col, grp.col, reg.col) - 1, keep.response = TRUE)
-  }
-  stats::formula(stats::delete.response(Terms))
-}
-
 #' @rdname predict.elo.run
 #' @export
 predict.elo.run <- function(object, newdata, ...)
